.. This file is part of Invenio
   Copyright (C) 2015 CERN.

   Invenio is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   Invenio is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Invenio; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

Chat rooms
==========

Gitter
------

We mostly use Gitter these days for both personal and group chat. You can access
our chat room here:

- `<https://gitter.im/inveniosoftware/invenio>`_

Google Hangouts
---------------

We are using "Invenio Developers" named hangout as well. Please contact
``info@invenio-software.org`` if you would like to be added.

The Hangouts room is joinable by invitation only. It broadcasts messages
to all developers, even those not currently logged in. Hence please use
it sparely for chit chat or getting targeted help; it is more useful for
broadcasting messages of wider general interest. Also, unlike mailing
list, the topics are inter-mixed. For wider discussions, you may want to
send an email to the mailing list and additionally alert people about it
via hangouts.

IRC
---

We are also using ``#invenio`` IRC channel at ``irc.freenode.net``. Please feel
free to drop by and discuss anything. However, the IRC channel is not used much;
people are mostly on Gitter nowadays.

The IRC room is easy to join and leave at will. It is used for discussions
between currently-logged-in persons, hence suitable for getting help or asking
for immediate reaction. There is no "offline" delivery of messages to persons
not currently logged in; please use our mailing list for messages of this type.
